# Generated by Django 3.2.7 on 2021-12-16 16:36

import django.core.validators
from django.db import migrations, models
from django.conf import settings

UPLOAD_SIZE_LIMIT_OBJECTS = [
    {
        "slug": "dataset_upload_size",
        "description": "The sum of sizes for the files of a dataset upload.",
        "max_size": settings.DEFAULT_MAX_UPLOAD_SIZE
    },
    {
        "slug": "document_upload_size",
        "description": "The maximum size for document files.",
        "max_size": settings.DEFAULT_MAX_UPLOAD_SIZE
    }
]

def create_upload_size_limit_objects(apps, schema_editor):
    UploadSizeLimit = apps.get_model("upload", "UploadSizeLimit")
    for obj in UPLOAD_SIZE_LIMIT_OBJECTS:
        UploadSizeLimit.objects.create(**obj)

def remove_upload_size_limit_objects(apps, schema_editor):
    UploadSizeLimit = apps.get_model("upload", "UploadSizeLimit")
    UploadSizeLimit.objects.all().delete()


class Migration(migrations.Migration):

    dependencies = [
        ('upload', '0031_upload_resume_url'),
    ]

    operations = [
        migrations.CreateModel(
            name='UploadSizeLimit',
            fields=[
                ('slug', models.SlugField(max_length=255, primary_key=True, serialize=False, unique=True, validators=[django.core.validators.MinLengthValidator(limit_value=3)])),
                ('description', models.TextField(blank=True, default=None, max_length=255, null=True)),
                ('max_size', models.PositiveBigIntegerField(default=104857600, help_text='The maximum file size allowed for upload (bytes).')),
            ],
            options={
                'ordering': ('slug',),
            },
        ),
        migrations.RunPython(create_upload_size_limit_objects, remove_upload_size_limit_objects),
    ]
